package azurerm

import "github.com/snyk/driftctl/pkg/resource"

func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInterface) {
	initAzureVirtualNetworkMetaData(resourceSchemaRepository)
	initAzureRouteTableMetaData(resourceSchemaRepository)
	initAzureRouteMetaData(resourceSchemaRepository)
	initAzureResourceGroupMetadata(resourceSchemaRepository)
	initAzureContainerRegistryMetadata(resourceSchemaRepository)
	initAzureFirewallMetadata(resourceSchemaRepository)
	initAzurePostgresqlServerMetadata(resourceSchemaRepository)
	initAzurePublicIPMetadata(resourceSchemaRepository)
	initAzurePostgresqlDatabaseMetadata(resourceSchemaRepository)
	initAzureNetworkSecurityGroupMetadata(resourceSchemaRepository)
	initAzureLoadBalancerMetadata(resourceSchemaRepository)
	initAzurePrivateDNSZoneMetaData(resourceSchemaRepository)
	initAzurePrivateDNSARecordMetaData(resourceSchemaRepository)
	initAzurePrivateDNSAAAARecordMetaData(resourceSchemaRepository)
	initAzurePrivateDNSPTRRecordMetaData(resourceSchemaRepository)
	initAzurePrivateDNSSRVRecordMetaData(resourceSchemaRepository)
	initAzurePrivateDNSMXRecordMetaData(resourceSchemaRepository)
	initAzurePrivateDNSTXTRecordMetaData(resourceSchemaRepository)
	initAzureImageMetaData(resourceSchemaRepository)
	initAzureSSHPublicKeyMetaData(resourceSchemaRepository)
	initAzurePrivateDNSCNameRecordMetaData(resourceSchemaRepository)
	initAzureLoadBalancerRuleMetadata(resourceSchemaRepository)
}
